@@ -2,7 +2,7 @@ use std::sync::Arc;
 
 use all4art_authservice_domain::{factories::ClearTextPasswordFactory, clear_text_password::ClearTextPassword, hashed_password::HashedPassword};
 
-struct ClearTextPasswordFactoryMock { 
+pub struct ClearTextPasswordFactoryMock { 
 
 }
 
@@ -12,7 +12,7 @@ impl ClearTextPasswordFactory for ClearTextPasswordFactoryMock {
     }
 }
 
-struct ClearTextPasswordMock { 
+pub struct ClearTextPasswordMock { 
 
 }
 
@@ -28,7 +28,7 @@ impl ClearTextPassword for ClearTextPasswordMock {
     }
 }
 
-struct HashedPasswordMock { 
+pub struct HashedPasswordMock { 
 
 }
 
